import { post, get, patch, del } from "./baseApi";

/**
 * Function wrapping POST request for adding a provider
 * @param {string} provider_email - email of provider
 * @param {string?} note - optional note
 */
export function addEmployee(provider_email, note) {
  return post("/employee/", { provider_email, note }).then(resp =>
    Promise.resolve(resp)
  );
}

/**
 * Function wrapping GET request for one employee detail
 * @param {string} uuid - employee UUID
 */
export function getEmployee(uuid) {
  return get(`/employee/${uuid}/`).then(resp => Promise.resolve(resp));
}

/**
 * Function wrapping PATCH request for updating a provider
 * @param {string} uuid - employee UUID
 * @param {string} provider_email - provider's email
 * @param {string?} note - optional note
 */
export function updateEmployee(uuid, provider_email, note) {
  return patch(`/employee/${uuid}`, { provider_email, note }).then(resp =>
    Promise.resolve(resp)
  );
}

/**
 * Function wrapping DELETE request for removing an employee
 * @param {string} uuid - employee UUID
 */
export function deleteEmployee(uuid) {
  return del(`/employee/${uuid}/`).then(resp => Promise.resolve(resp));
}
